==> pmml-model-1.0.6-sources.jar: org/dmg/pmml/Coefficients.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3._2001.xmlschema.Adapter1;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Coefficient" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="numberOfCoefficients" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="absoluteValue" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" default="0" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "coefficients"
})
@XmlRootElement(name = "Coefficients")
public class Coefficients
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "Coefficient", required = true)
    protected List<Coefficient> coefficients;
    @XmlAttribute(name = "numberOfCoefficients")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer numberOfCoefficients;
    @XmlAttribute(name = "absoluteValue")
    protected Double absoluteValue;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the coefficients property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the coefficients property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getCoefficients().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Coefficient }
     * 
     * 
     */
    public List<Coefficient> getCoefficients() {
        if (coefficients == null) {
            coefficients = new ArrayList<Coefficient>();
        }
        return this.coefficients;
    }

    /**
     * Gets the value of the numberOfCoefficients property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getNumberOfCoefficients() {
        return numberOfCoefficients;
    }

    /**
     * Sets the value of the numberOfCoefficients property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNumberOfCoefficients(Integer value) {
        this.numberOfCoefficients = value;
    }

    /**
     * Gets the value of the absoluteValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public double getAbsoluteValue() {
        if (absoluteValue == null) {
            return  0.0D;
        } else {
            return absoluteValue;
        }
    }

    /**
     * Sets the value of the absoluteValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setAbsoluteValue(Double value) {
        this.absoluteValue = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof Coefficients)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final Coefficients that = ((Coefficients) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            List<Coefficient> lhsCoefficients;
            lhsCoefficients = (((this.coefficients!= null)&&(!this.coefficients.isEmpty()))?this.getCoefficients():null);
            List<Coefficient> rhsCoefficients;
            rhsCoefficients = (((that.coefficients!= null)&&(!that.coefficients.isEmpty()))?that.getCoefficients():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "coefficients", lhsCoefficients), LocatorUtils.property(thatLocator, "coefficients", rhsCoefficients), lhsCoefficients, rhsCoefficients)) {
                return false;
            }
        }
        {
            Integer lhsNumberOfCoefficients;
            lhsNumberOfCoefficients = this.getNumberOfCoefficients();
            Integer rhsNumberOfCoefficients;
            rhsNumberOfCoefficients = that.getNumberOfCoefficients();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfCoefficients", lhsNumberOfCoefficients), LocatorUtils.property(thatLocator, "numberOfCoefficients", rhsNumberOfCoefficients), lhsNumberOfCoefficients, rhsNumberOfCoefficients)) {
                return false;
            }
        }
        {
            double lhsAbsoluteValue;
            lhsAbsoluteValue = ((this.absoluteValue!= null)?this.getAbsoluteValue(): 0.0D);
            double rhsAbsoluteValue;
            rhsAbsoluteValue = ((that.absoluteValue!= null)?that.getAbsoluteValue(): 0.0D);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "absoluteValue", lhsAbsoluteValue), LocatorUtils.property(thatLocator, "absoluteValue", rhsAbsoluteValue), lhsAbsoluteValue, rhsAbsoluteValue)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            List<Coefficient> theCoefficients;
            theCoefficients = (((this.coefficients!= null)&&(!this.coefficients.isEmpty()))?this.getCoefficients():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "coefficients", theCoefficients), currentHashCode, theCoefficients);
        }
        {
            Integer theNumberOfCoefficients;
            theNumberOfCoefficients = this.getNumberOfCoefficients();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfCoefficients", theNumberOfCoefficients), currentHashCode, theNumberOfCoefficients);
        }
        {
            double theAbsoluteValue;
            theAbsoluteValue = ((this.absoluteValue!= null)?this.getAbsoluteValue(): 0.0D);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "absoluteValue", theAbsoluteValue), currentHashCode, theAbsoluteValue);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            List<Coefficient> theCoefficients;
            theCoefficients = (((this.coefficients!= null)&&(!this.coefficients.isEmpty()))?this.getCoefficients():null);
            strategy.appendField(locator, this, "coefficients", buffer, theCoefficients);
        }
        {
            Integer theNumberOfCoefficients;
            theNumberOfCoefficients = this.getNumberOfCoefficients();
            strategy.appendField(locator, this, "numberOfCoefficients", buffer, theNumberOfCoefficients);
        }
        {
            double theAbsoluteValue;
            theAbsoluteValue = ((this.absoluteValue!= null)?this.getAbsoluteValue(): 0.0D);
            strategy.appendField(locator, this, "absoluteValue", buffer, theAbsoluteValue);
        }
        return buffer;
    }

}

==> pmml-model-1.0.9-sources.jar: org/dmg/pmml/Coefficients.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3._2001.xmlschema.Adapter1;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Coefficient" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="numberOfCoefficients" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="absoluteValue" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" default="0" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "coefficients"
})
@XmlRootElement(name = "Coefficients")
public class Coefficients
    extends PMMLObject
    implements Locatable, Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "Coefficient", required = true)
    protected List<Coefficient> coefficients;
    @XmlAttribute(name = "numberOfCoefficients")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer numberOfCoefficients;
    @XmlAttribute(name = "absoluteValue")
    protected Double absoluteValue;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the coefficients property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the coefficients property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getCoefficients().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Coefficient }
     * 
     * 
     */
    public List<Coefficient> getCoefficients() {
        if (coefficients == null) {
            coefficients = new ArrayList<Coefficient>();
        }
        return this.coefficients;
    }

    /**
     * Gets the value of the numberOfCoefficients property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getNumberOfCoefficients() {
        return numberOfCoefficients;
    }

    /**
     * Sets the value of the numberOfCoefficients property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNumberOfCoefficients(Integer value) {
        this.numberOfCoefficients = value;
    }

    /**
     * Gets the value of the absoluteValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public double getAbsoluteValue() {
        if (absoluteValue == null) {
            return  0.0D;
        } else {
            return absoluteValue;
        }
    }

    /**
     * Sets the value of the absoluteValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setAbsoluteValue(Double value) {
        this.absoluteValue = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof Coefficients)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final Coefficients that = ((Coefficients) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            List<Coefficient> lhsCoefficients;
            lhsCoefficients = (((this.coefficients!= null)&&(!this.coefficients.isEmpty()))?this.getCoefficients():null);
            List<Coefficient> rhsCoefficients;
            rhsCoefficients = (((that.coefficients!= null)&&(!that.coefficients.isEmpty()))?that.getCoefficients():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "coefficients", lhsCoefficients), LocatorUtils.property(thatLocator, "coefficients", rhsCoefficients), lhsCoefficients, rhsCoefficients)) {
                return false;
            }
        }
        {
            Integer lhsNumberOfCoefficients;
            lhsNumberOfCoefficients = this.getNumberOfCoefficients();
            Integer rhsNumberOfCoefficients;
            rhsNumberOfCoefficients = that.getNumberOfCoefficients();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfCoefficients", lhsNumberOfCoefficients), LocatorUtils.property(thatLocator, "numberOfCoefficients", rhsNumberOfCoefficients), lhsNumberOfCoefficients, rhsNumberOfCoefficients)) {
                return false;
            }
        }
        {
            double lhsAbsoluteValue;
            lhsAbsoluteValue = ((this.absoluteValue!= null)?this.getAbsoluteValue(): 0.0D);
            double rhsAbsoluteValue;
            rhsAbsoluteValue = ((that.absoluteValue!= null)?that.getAbsoluteValue(): 0.0D);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "absoluteValue", lhsAbsoluteValue), LocatorUtils.property(thatLocator, "absoluteValue", rhsAbsoluteValue), lhsAbsoluteValue, rhsAbsoluteValue)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            List<Coefficient> theCoefficients;
            theCoefficients = (((this.coefficients!= null)&&(!this.coefficients.isEmpty()))?this.getCoefficients():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "coefficients", theCoefficients), currentHashCode, theCoefficients);
        }
        {
            Integer theNumberOfCoefficients;
            theNumberOfCoefficients = this.getNumberOfCoefficients();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfCoefficients", theNumberOfCoefficients), currentHashCode, theNumberOfCoefficients);
        }
        {
            double theAbsoluteValue;
            theAbsoluteValue = ((this.absoluteValue!= null)?this.getAbsoluteValue(): 0.0D);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "absoluteValue", theAbsoluteValue), currentHashCode, theAbsoluteValue);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            List<Coefficient> theCoefficients;
            theCoefficients = (((this.coefficients!= null)&&(!this.coefficients.isEmpty()))?this.getCoefficients():null);
            strategy.appendField(locator, this, "coefficients", buffer, theCoefficients);
        }
        {
            Integer theNumberOfCoefficients;
            theNumberOfCoefficients = this.getNumberOfCoefficients();
            strategy.appendField(locator, this, "numberOfCoefficients", buffer, theNumberOfCoefficients);
        }
        {
            double theAbsoluteValue;
            theAbsoluteValue = ((this.absoluteValue!= null)?this.getAbsoluteValue(): 0.0D);
            strategy.appendField(locator, this, "absoluteValue", buffer, theAbsoluteValue);
        }
        return buffer;
    }

}
